/*
 * Script.cpp:
 *
 * This file is responsible for interpreting scripts.
 *
 * Copyright (c) Malcolm Smith 2001-2007.  No warranty is provided.
 */

#include "pch.h"

#ifdef SCRIPTING

#define MAX_PARAM 16

static int scrAddHandler(LIST * List,LPTSTR * szParam)
{
	LPTSTR a;
	a=_tcsrchr(szParam[0],'.');
	if (a) {
		a=a+1;
	} else {
		a=szParam[0];
	}
	return MplayAddHandler(a,szParam[1]);
}


static int scrClear(LIST * List,LPTSTR * szParam)
{
	return MplayClearList(List);
}

static int scrClearHandlers(LIST * List,LPTSTR * szParam)
{
	return MplayResetHandlers();
}


static int scrHide(LIST * List,LPTSTR * szParam)
{
	return MplayDispWindow(GethWndMain(),FALSE);
}


static int scrImport(LIST * List,LPTSTR * szParam)
{
	HANDLE hFind;
	pi_find fd;
	if ((hFind = MplayFindFirst(szParam[0], &fd)) != INVALID_FIND_VALUE) {
		MplayFindClose(hFind);
		if (MplayGetAttr(&fd) & FA_SUBDIR) {
			return MplayGenerateTree(List,szParam[0]);
		} else {
			return MplayInputFile(List,szParam[0]);
		}
	}
	return MPLAY_ERROR_BAD_PATH;
}

static int scrOntop(LIST * List,LPTSTR * szParam)
{
	BOOL onTopState = TRUE;
	if (szParam[0]) {
		if (!_tcsicmp(szParam[0], _T("false")))
			onTopState = FALSE;
	}
	return MplaySetOnTop(GethWndMain(), onTopState);
}


static int scrPlay(LIST * List,LPTSTR * szParam)
{
	unsigned long ul=0;
	if (szParam[0])
		_stscanf(szParam[0], _T("%u"), &ul);
	return MplayPlayMediaFile(GethWndMain(),List,(int)ul);
}

static int scrShow(LIST * List,LPTSTR * szParam)
{
	return MplayDispWindow(GethWndMain(), TRUE);
}


static int scrShuffle(LIST * List,LPTSTR * szParam)
{
	return MplayShuffleList(List);
}

static int scrSort(LIST * List,LPTSTR * szParam)
{
	int sorttype;
	if (!_tcscmp(szParam[0],_T("path"))) {
		sorttype = SORT_PATH;
	} else {
		if (!_tcscmp(szParam[0],_T("file"))) {
			sorttype = SORT_FILE;
		} else {
			sorttype = SORT_DISPLAY;
		}
	}
	return MplaySortList(List, sorttype);
}

static int scrTracker(LIST * List,LPTSTR * szParam)
{
	BOOL trackerState = TRUE;
	if (szParam[0]) {  
		if (!_tcscmp(szParam[0],_T("false")))
			trackerState = FALSE;
	}

	return MplaySetTracker(GethWndMain(), trackerState);
}

int
MplayPlayScript(LIST * List, LPTSTR szFile)
{
	FILE * fp;
	CHAR szRawLine[1024];
#ifdef UNICODE
	TCHAR szUniLine[1024];
#endif
	LPTSTR szLine;
	LPTSTR szParam[MAX_PARAM];
	LPTSTR a;
	LPSTR b;
	int i;

	fp=_tfopen(szFile, _T("r"));
	if (!fp) {
		return MPLAY_ERROR_BAD_PATH;
	}

	//
	// FIXME
	//
	// This assumes input is always ANSI.
	//

	fgets(szRawLine, sizeof(szRawLine), fp);
	b=strchr(szRawLine,'\r');
	if (b) b[0]='\0';
	b=strchr(szRawLine,'\n');
	if (b) b[0]='\0';
#ifdef UNICODE
	OemToChar(szRawLine, szUniLine);
	szLine = szUniLine;
#else
	szLine = szRawLine;
#endif


	while (!feof(fp)) {
		a=_tcschr(szLine,'#');
		if (a) a[0]='\0';
		if (_tcslen(szLine)) {
			for (i=0;i<MAX_PARAM;i++)
				szParam[i]=NULL;
			a=_tcschr(szLine,' ');
			if (a) {
				a[0]='\0';
				szParam[0]=a+1;
				i=0;
				while ((a=_tcschr(szParam[i],','))&&(i<MAX_PARAM)) {
					a[0]='\0';
					i++;
					szParam[i]=a+1;
				}

			}
			
			if (!_tcscmp(szLine, _T("AddHandler"))) scrAddHandler(List,szParam);
			if (!_tcscmp(szLine, _T("Clear"))) scrClear(List,szParam);
			if (!_tcscmp(szLine, _T("ClearHandlers"))) scrClearHandlers(List,szParam);
			if (!_tcscmp(szLine, _T("Hide"))) scrHide(List,szParam);
			if (!_tcscmp(szLine, _T("Import"))) scrImport(List,szParam);
			if (!_tcscmp(szLine, _T("OnTop"))) scrOntop(List,szParam);
			if (!_tcscmp(szLine, _T("Play"))) scrPlay(List,szParam);
			if (!_tcscmp(szLine, _T("Show"))) scrShow(List,szParam);
			if (!_tcscmp(szLine, _T("Shuffle"))) scrShuffle(List,szParam);
			if (!_tcscmp(szLine, _T("Sort"))) scrSort(List,szParam);
			if (!_tcscmp(szLine, _T("Tracker"))) scrTracker(List,szParam);
		}
		fgets(szRawLine, sizeof(szRawLine), fp);
		b=strchr(szRawLine,'\r');
		if (b) b[0]='\0';
		b=strchr(szRawLine,'\n');
		if (b) b[0]='\0';
#ifdef UNICODE
		OemToChar(szRawLine, szUniLine);
		szLine = szUniLine;
#else
		szLine = szRawLine;
#endif

	}
	fclose(fp);
	return MPLAY_ERROR_SUCCESS;
}

#endif


